


import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/access_management/booking_system/bloc/sidebar/sidebar_event.dart';
import 'package:syncrow_web/pages/access_management/booking_system/bloc/sidebar/sidebar_state.dart';
import 'package:syncrow_web/pages/access_management/booking_system/model/bookable_room.dart';
import 'package:syncrow_web/utils/constants/assets.dart';

class SidebarBloc extends Bloc<SidebarEvent, SidebarState> {
  SidebarBloc() : super(SidebarState(
    allRooms: [],
    displayedRooms: [],
    isLoading: true,
  )) {
    on<LoadRoomsEvent>(_onLoadRooms);
    on<SelectRoomEvent>(_onSelectRoom);
    on<SearchRoomsEvent>(_onSearchRooms);
  }

  Future<void> _onLoadRooms(
    LoadRoomsEvent event,
    Emitter<SidebarState> emit,
  ) async {
    try {
      emit(state.copyWith(isLoading: true));
      
      await Future.delayed(const Duration(seconds: 1));
            final rooms = List.generate(15, (index) => BookableRoom(
        id: index,
        name: 'Meeting Room ${index + 1}',
        capacity: [4, 6, 8, 10][index % 4],
        iconAsset: Assets.AtoZIcon,
      ));
      
      emit(state.copyWith(
        allRooms: rooms,
        displayedRooms: rooms,
        isLoading: false,
      ));
    } catch (e) {
      emit(state.copyWith(
        isLoading: false,
        errorMessage: 'Failed to load rooms',
      ));
    }
  }

  void _onSelectRoom(
    SelectRoomEvent event,
    Emitter<SidebarState> emit,
  ) {
    emit(state.copyWith(selectedRoomId: event.roomId));
  }

  void _onSearchRooms(
    SearchRoomsEvent event,
    Emitter<SidebarState> emit,
  ) {
    if (event.query.isEmpty) {
      emit(state.copyWith(displayedRooms: state.allRooms));
    } else {
      final filtered = state.allRooms.where((room) =>
          room.name.toLowerCase().contains(event.query.toLowerCase())).toList();
      emit(state.copyWith(displayedRooms: filtered));
    }
  }
}