
import 'package:flutter/material.dart';
import 'package:syncrow_web/pages/access_management/booking_system/model/bookable_room.dart';
import 'package:syncrow_web/utils/color_manager.dart';

class RoomListItem extends StatelessWidget {
  final BookableRoom room;
  final bool isSelected;
  final VoidCallback onTap;

  const RoomListItem({
    required this.room,
    required this.isSelected,
    required this.onTap,
  });

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: onTap,
      hoverColor: ColorsManager.primaryColor.withOpacity(0.05),
      child: Container(
        height: 40,
        padding: const EdgeInsets.symmetric(horizontal: 16.0),
        child: Row(
          children: [
            IgnorePointer(
              child: Radio<int>(
                value: room.id,
                groupValue: isSelected ? room.id : null,
                onChanged: (value) {},
                activeColor: ColorsManager.primaryColor,
              ),
            ),
            const SizedBox(width: 12),
            Expanded(
              child: Text(
                room.name,
                style: Theme.of(context).textTheme.bodyMedium?.copyWith(
                      color: ColorsManager.textGray,
                      fontWeight:
                          isSelected ? FontWeight.w600 : FontWeight.normal,
                    ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
